
local ffi = require 'ffi'

ffi.cdef[[
typedef struct {
  float x, y;
  float u, v;
} vertexStruct;
]]
-- you could also add RGBA if you want to do vertex Colors

local windowWidth, windowHeight = love.graphics.getDimensions()
local windowScale = 8
local width = windowWidth / windowScale 
local height = windowHeight / windowScale

love.graphics.setDefaultFilter("nearest","nearest")
local canvas = love.graphics.newCanvas(width, height)

local vertexNumber = 4
local vertexSize = ffi.sizeof('vertexStruct') * vertexNumber
local vertexData = love.data.newByteData( vertexSize )
local vertexPointer = ffi.cast("vertexStruct*", vertexData:getFFIPointer())

local startVertices = {{10,10},{90,20}, {70,60}, {20,50}} -- you could use a C struct or byteData with a pointer instead, it's faster if you change this often
local vertexFormat = {
  {"VertexPosition", "float", 2},
  {"VertexTexCoord", "float", 2}
--  {"VertexColor", "byte", 4},  you could also add RGBA if you want to do vertex colors
  }


local mesh = love.graphics.newMesh( vertexFormat, vertexNumber, "fan", "static" )

local texture = love.graphics.newImage('pixlove.png')
      texture:setWrap("repeat","repeat")
      texture:setFilter("nearest","nearest")
local textureScaleFactor = 1
local textureScale = texture:getWidth() * textureScaleFactor

mesh:setTexture( texture )

for i = 1, vertexNumber  do
  vertexPointer[i-1].x= startVertices[i][1]
  vertexPointer[i-1].y= startVertices[i][2]
  vertexPointer[i-1].u= startVertices[i][1] / textureScale
  vertexPointer[i-1].v= startVertices[i][2] / textureScale
end

mesh:setVertices( vertexData )

love.graphics.setCanvas( canvas )
love.graphics.draw(mesh, 0,0)
love.graphics.setCanvas( )



function love.draw()

  love.graphics.draw(canvas,0,0,0,windowScale,windowScale)

end


